#!/bin/bash
CONFIGURE_ARGS="--enable-debug --target-list=x86_64-softmmu"
QEMU_ARGS=("-intsvc" "0.0.0.0:4444" "-nographic" "-kernel" "./bzImage" "-initrd" "initramfs.cpio.gz" "-machine" "accel=tcg" "-device" "edu" "-append" "earlyprintk=serial,ttyS0 console=ttyS0 loglevel=3 oops=panic panic=1")

set -e

usage() {
    echo "Usage: $0 [options]"
    echo "Options:"
    echo "  -d, --debug     Enable debug mode"
    echo "  -c, --reconfig  Reconfigure qemu"
    echo "  -c, --clean     Clean build directory"
    echo "  -b, --build     Build qemu"
}

# Parse arguments

while [ $# -gt 0 ]; do
    case "$1" in
        -d|--debug)
            DEBUG=1
            ;;
        -r|--reconfig)
            RECONFIG=1
            ;;
        -c|--clean)
            CLEAN=1
            ;;
        -b|--build)
            BUILD=1
            ;;
        -h|--help)
            usage
            exit 0
            ;;
        *)
            echo "Unknown option: $1"
            usage
            exit 1
            ;;
    esac
    shift
done

pushd qemu-8.1.2

if [ -n "$CLEAN" ]; then
    rm -rf build
    mkdir build
    RECONFIG=1
fi

pushd build

if [ -n "$RECONFIG" ]; then
    echo "Configuring qemu"
    ../configure --prefix=$(pwd)/build $CONFIGURE_ARGS
    BUILD=1
fi

if [ -n "$BUILD" ]; then
    echo "Building qemu"
    make -j$(nproc)
fi

popd
popd

if [ -n "$DEBUG" ]; then
    echo "Starting qemu in debug mode"
    gdb --args qemu-8.1.2/build/x86_64-softmmu/qemu-system-x86_64 "${QEMU_ARGS[@]}"
else
    echo "Starting qemu"
    qemu-8.1.2/build/x86_64-softmmu/qemu-system-x86_64 "${QEMU_ARGS[@]}"
fi
